@@ -48,23 +48,19 @@ use constant CUPSD              => '/etc/cups/cupsd.conf';
 use constant CUPSPPD 		=> '/etc/cups/ppd/';
 use constant START_TAG		=> '# __EBOX__ TAG #';
 use constant END_TAG		=> '# END __EBOX__ TAG #';
+use constant TEST_PAGE		=> '/usr/share/cups/data/testprint.ps';
 
 sub _create
 {
 	my $class = shift;
 	my $self = $class->SUPER::_create(name => 'printers',
-					  printableName => __('Printer Sharing'),
+					  printableName => __n('Printer Sharing'),
 					  domain => 'ebox-printers' );
 	bless($self, $class);
 	$self->{'cups'} = new Net::CUPS;
 	return $self;
 }
 
-sub domain
-{
-	return 'ebox-printers';
-}
-
 # Method: actions
 #
 # 	Override EBox::Module::Service::actions
@@ -229,7 +225,7 @@ sub manufacturerModels($$)
 	my $db = new Foomatic::DB;
 	my $manufacturer = $self->manufacturer($id);
 	my @models = sort ($db->get_models_by_make($manufacturer));
-	push (@models, 'Raw');
+	push (@models, 'Raw') unless (@models);
 	return \@models;
 }
 
@@ -272,8 +268,8 @@ sub driversForPrinter($$)
 		return ['Raw'];
 	}
 	my $db = new Foomatic::DB;
-	#my @drivers = grep(! /^(gimp.*)|(hpdj)/,
-	my @drivers = $db->get_drivers_for_printer($printer);
+	my @drivers = 
+		grep(! /^Postscript.+/, $db->get_drivers_for_printer($printer));
 	if (@drivers) {
 		return \@drivers;
 	} else {
@@ -288,7 +284,7 @@ sub menu
 
 	my $folder = new EBox::Menu::Folder('name' => 'Printers',
 					    'text' => $self->printableName(),
-                        'separator' => __('Office'),
+                        'separator' => 'Office',
                         'order' => 550);
 
 	$folder->add(new EBox::Menu::Item('url' => 'Printers/AddPrinterUI',
@@ -1132,14 +1128,13 @@ sub printerJobs # (printerid, completed)
 
 	my @jobs;
 	if ($printer) {
-		@jobs = $printer->getJobs(0, $completed);
+		for my $jobId  ($printer->getJobs(0, $completed)) {
+			push (@jobs, $printer->getJob($jobId));
+		}
 	}
+	
+	return \@jobs;
 
-	if (@jobs and ($jobs[0])) {
-		return \@jobs;
-	} else {
-		return [];
-	}
 }
 
 sub cancelJob # (printername, jobid)
@@ -1153,7 +1148,44 @@ sub cancelJob # (printername, jobid)
 						     'value' => "$printer");
 	}
 
-	cupsCancelJob($printer, $jobid);
+	my $dest = $self->{'cups'}->getDestination($printer);
+	$dest->cancelJob($jobid);
+}
+
+# Method: isPrinterInCups
+#
+#	Check if a printers is already available in CUPS
+# Return:
+#
+#	boolean - 1 available, 0 false
+sub isPrinterInCups
+{
+	my ($self, $printer) = @_;
+	my $cups = Net::CUPS->new();
+	for my $dest ($cups->getDestinations()) {
+		return 1 if ($printer eq $dest->getName());
+	}
+	return 0;
+}
+
+# Method: printTestPage
+#
+#	Print a test page
+sub printTestPage
+{
+	my ($self, $id) = @_;
+
+	unless ($self->_printerIdExists($id)) {
+		throw EBox::Exceptions::DataNotFound('data'  => __('Printer'),
+						     'value' => "$id");
+	}
+	unless ($self->_printerConfigured($id)) {
+		throw EBox::Exceptions::External(__('Printer not configured'));
+	}
+
+	my $info = $self->_printerInfo($id);
+	my $printer = $self->{'cups'}->getDestination($info->{'name'});
+	$printer->printFile(TEST_PAGE, 'test page');
 }
 
 sub usbDevices
